#include "Oscillograph.lua"
#include "UIBodyState.lua"

HEALTH_UI_BACKGROUND_WIDTH = 300
HEALTH_UI_BACKGROUND_HEIGHT= 110
HEALTH_UI_DETAIL_BACKGROUND_WIDTH = 150
HEALTH_UI_DETAIL_BACKGROUND_HEIGHT= 230
HEALTH_UI_INFO_BACKGROUND_HEIGHT= 24

showHealthMenu = false
showHealthDetails = false

bodyState = HEALTHY_BODY_STATE

function DrawUiHealthOverlay(dt)
	if not showHealthMenu then return end
	if bodyState == nil then return end		

	UiTranslate(400,400)	
	
	local healthText = "All Good"
	if bodyState.overall == "injured" then healthText = "Injured" end
	if bodyState.overall == "dead" then healthText = "Dead" end
	
	UiPush()
		drawBackground()
		writeText(healthText,30,110,34,true)
		UiPush()
			UiTranslate(110,40)
			if bodyState.overall == "dead" then
				UiDrawHeartbeatFlatline(dt,HEALTH_UI_BACKGROUND_WIDTH-110-20, 20,30)
				UiTranslate(0,30)
				UiDrawOxygenFlatline(dt,HEALTH_UI_BACKGROUND_WIDTH-110-20, 20,30)
			elseif bodyState.overall == "injured" then
				UiDrawHeartbeatOscillograph(dt,HEALTH_UI_BACKGROUND_WIDTH-110-20,20,10,30,200)
				UiTranslate(0,30)
				UiDrawOxygenOscillograph(dt,HEALTH_UI_BACKGROUND_WIDTH-110-20,20,10,30,200)
			else 
				UiDrawHeartbeatOscillograph(dt,HEALTH_UI_BACKGROUND_WIDTH-110-20,20,5,30,200)
				UiTranslate(0,30)
				UiDrawOxygenOscillograph(dt,HEALTH_UI_BACKGROUND_WIDTH-110-20,20,5,30,200)
			end			
		UiPop()
		writeText("Blood",18,110,60)
		drawRect(110,67,HEALTH_UI_BACKGROUND_WIDTH-110-20,1,1,1,1,1)
		writeText("Oxygen",18,110,85)
		UiTranslate(0,HEALTH_UI_BACKGROUND_HEIGHT+3)
		drawInfoBackground()
		writeText("Press X for more info",18,110,18)			
	UiPop()
	if showHealthDetails then
		UiPush()
			UiTranslate(HEALTH_UI_BACKGROUND_WIDTH+5,-(HEALTH_UI_DETAIL_BACKGROUND_HEIGHT-HEALTH_UI_BACKGROUND_HEIGHT-HEALTH_UI_INFO_BACKGROUND_HEIGHT-3))
			drawDetailBackground()
					
			local y = 20
			for i,effect in ipairs(bodyState.head.effects) do				
				writeText("Head " .. effect.text,18,10,y, false,effect.color)
				y=y+20
			end
			for i,effect in ipairs(bodyState.body.effects) do				
				writeText("Body " .. effect.text,18,10,y, false,effect.color)
				y=y+20
			end
			for i,effect in ipairs(bodyState.leftArm.effects) do				
				writeText("Left arm " .. effect.text,18,10,y, false,effect.color)
				y=y+20
			end
			for i,effect in ipairs(bodyState.rightArm.effects) do				
				writeText("Right arm " .. effect.text,18,10,y, false,effect.color)
				y=y+20
			end
			for i,effect in ipairs(bodyState.leftLeg.effects) do				
				writeText("Left leg " .. effect.text,18,10,y, false,effect.color)
				y=y+20
			end
			for i,effect in ipairs(bodyState.rightLeg.effects) do				
				writeText("Right leg " .. effect.text,18,10,y, false,effect.color)
				y=y+20
			end
			for i,effect in ipairs(bodyState.effects) do
				writeText(effect.text,18,10,y, false,effect.color)
				y=y+20
			end
			
			local startHeight = 160
			for i, effect in ipairs(bodyState.effects) do
				writeText(effect.text,18,10,startHeight,false,effect.color)
				startHeight = startHeight + 20
			end
		UiPop()
	end
	UiTranslate(14,-10)
	UiDrawBodyState(bodyState)
end

function drawBackground()
	drawRect(0,0,HEALTH_UI_BACKGROUND_WIDTH,HEALTH_UI_BACKGROUND_HEIGHT,0,0,0,1)
end

function drawInfoBackground()
	drawRect(0,0,HEALTH_UI_BACKGROUND_WIDTH,HEALTH_UI_INFO_BACKGROUND_HEIGHT,0,0,0,1)
end

function drawDetailBackground()
	drawRect(0,0,HEALTH_UI_DETAIL_BACKGROUND_WIDTH,HEALTH_UI_DETAIL_BACKGROUND_HEIGHT,0,0,0,1)
end

function writeText(text, size, x,y ,bold, color)
	UiPush()
		if color ~= nil then
			UiColor(color.r,color.g,color.b)
		end
		UiTranslate(x,y)
		if bold then
			UiFont("bold.ttf", size)
		else
			UiFont("regular.ttf", size)
		end
		UiText(text)
	UiPop()
end

function ToggleUiHealthOverlay()	
	showHealthMenu = not showHealthMenu
	showHealthDetails = showHealthMenu and showHealthDetails
end

function ToggleUiHealthDetailsOverlay()
	if showHealthMenu then
		showHealthDetails = not showHealthDetails
	end
end

function HideUiHealthOverlay()
	showHealthMenu = false
end